summaryrefslogtreecommitdiff
path: root/app/assets/javascripts/render_gfm.js
diff options
context:
space:
mode:
Diffstat (limited to 'app/assets/javascripts/render_gfm.js')
-rw-r--r--app/assets/javascripts/render_gfm.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/app/assets/javascripts/render_gfm.js b/app/assets/javascripts/render_gfm.js
index bcdc0fd67b8..bf6fc0ec305 100644
--- a/app/assets/javascripts/render_gfm.js
+++ b/app/assets/javascripts/render_gfm.js
@@ -2,12 +2,13 @@
// Render Gitlab flavoured Markdown
//
// Delegates to syntax highlight and render math
//
(function() {
$.fn.renderGFM = function() {
this.find('.js-syntax-highlight').syntaxHighlight();
this.find('.js-render-math').renderMath();
+ this.find('.js-render-mermaid').renderMermaid();
return this;
};
@@ -2,12 +2,13 @@
// Render Gitlab flavoured Markdown
//
-// Delegates to syntax highlight and render math
+// Delegates to syntax highlight and render math & mermaid diagrams.
//
(function() {